{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "hr",
  "action.edit": "Uredi stranicu",
  "action.skip": "Preskočite na sadržaj",
  "announce.dismiss": "Ne prikazuj ovo opet",
  "clipboard.copy": "Kopirajte u međuspremnik",
  "clipboard.copied": "Kopirano u međuspremnik",
  "consent.accept": "Prihvati",
  "consent.manage": "Upravljaj postavkama",
  "consent.reject": "Odbij",
  "footer": "Podnožje",
  "footer.next": "Sljedeće",
  "footer.previous": "Prethodno",
  "header": "Zaglavlje",
  "meta.comments": "Komentari",
  "meta.source": "Izvor",
  "nav": "Navigacija",
  "search": "Pretraživanje",
  "search.placeholder": "Pretraživanje",
  "search.share": "Podijeli",
  "search.reset": "Očisti",
  "search.result.initializer": "Inicijaliziranje pretraživanja",
  "search.result.placeholder": "Unesite pojam pretraživanja",
  "search.result.none": "Ništa nije pronađeno",
  "search.result.one": "1 rezultat pretraživanja",
  "search.result.other": "# rezultata pretraživanja",
  "search.result.more.one": "1 rezultat na ovoj stranici",
  "search.result.more.other": "# rezultata na ovoj stranici",
  "search.result.term.missing": "Nedostaje",
  "select.language": "Odabir jezika",
  "select.version": "Odabir verzije",
  "source": "Idite u repozitorij",
  "source.file.date.created": "Stvoreno",
  "source.file.date.updated": "Zadnje ažuriranje",
  "tabs": "Kartice",
  "toc": "Sadržaj",
  "top": "Vratite se na vrh"
}[key] }}{% endmacro %}
